"""Compute a Time Average of a Time Strand with user-specified min and max solution time limits

usage:

    > python cpfd_TimeAverage.py

Necessary modules
-----------------
cpfd_tpmath
    Useful Mathematical Utilities for PyTecplot (modified by CPFD to add tMin and tMax)
tputils
    Generic PyTecplot Utilities


Description
-----------
To run this script we must first enable PyTecplot Connections via the Scripting menu.
The tpmath and tputils modules are also required.

Execute the script from a command prompt or terminal.
This will prompt for which Strand to average.
The strand number can be found in the Dataset Information dialog.
A strand is simply an integer which identifies a collection of zones through time.
Once we enter the strand number the script will handle the zone duplication
and execution of the formulas to average the results.

The script will also ask for tMin and tMax, which are the minimum and maximum
solution times to be included in the average.  If you do not want to apply a
minimum or maximum time, simply press enter and no limit will be applied.

When the script is finished, activate the Time Average zone to view results.

"""
import tecplot as tp
import cpfd_tpmath as tpmath
import tputils

tp.session.connect()
in_strand = input("Which strand do you want to average? Enter the strand number or enter 'all': ")
tMin = input("Minimum solution time to include in average (or press enter for no minimum): ")
tMax = input("Maximum solution time to include in average (or press enter for no maximum): ")

try:
    tMin = float(tMin)
except:
    tMin = None

try:
    tMax = float(tMax)
except:
    tMax = None

with tp.session.suspend():
    dataset = tp.active_frame().dataset

    # variables_to_average = [dataset.variable("salinity"), dataset.variable("temp")]
    # constant_variables = [dataset.variable("x"), dataset.variable("y")]
    variables_to_average = dataset.variables()
    constant_variables = None

    zones_by_strand = tputils.get_zones_by_strand(dataset)
    try:
        strand_to_average = int(in_strand)
        source_zones = zones_by_strand[strand_to_average]
        tpmath.compute_average(source_zones, variables_to_average, constant_variables, tMin=tMin, tMax=tMax)
    except (TypeError, ValueError):  # Assume the user typed "all"
        for strand, source_zones in zones_by_strand.items():
            tpmath.compute_average(source_zones, variables_to_average, constant_variables, tMin=tMin, tMax=tMax)
